<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Angebote',
'LBL_MODULE_TITLE'=>'Angebote: Home',
'LBL_SEARCH_FORM_TITLE'=>'Angebote suchen',
'LBL_LIST_FORM_TITLE'=>'Angebote',
'LBL_NEW_FORM_TITLE'=>'Neues Angebot',
'LBL_MEMBER_ORG_FORM_TITLE'=>'Mitgliedsorganisation',

'LBL_LIST_ACCOUNT_NAME'=>'Organisation',
'LBL_RELATED_PRODUCTS'=>'Artikel',
'LBL_LIST_CITY'=>'Ort',
'LBL_LIST_WEBSITE'=>'Webseite',
'LBL_LIST_STATE'=>'Bundesland',
'LBL_LIST_PHONE'=>'Telefon',
'LBL_LIST_EMAIL_ADDRESS'=>'E-Mail',
'LBL_LIST_CONTACT_NAME'=>'Person',

//DON'T CONVERT THESE THEY ARE MAPPINGS
'db_name' => 'LBL_LIST_ACCOUNT_NAME',
'db_website' => 'LBL_LIST_WEBSITE',
'db_billing_address_city' => 'LBL_LIST_CITY',

//END DON'T CONVERT

'LBL_ACCOUNT'=>'Organisation:',
'LBL_PHONE'=>'Telefon:',
'LBL_WEBSITE'=>'Webseite:',
'LBL_FAX'=>'Fax:',
'LBL_TICKER_SYMBOL'=>'Org. Namenszusatz:',
'LBL_OTHER_PHONE'=>'weiteres Telefon:',
'LBL_ANY_PHONE'=>'anderes Telefon:',
'LBL_MEMBER_OF'=>'Mitglied von:',
'LBL_EMAIL'=>'E-Mail:',
'LBL_EMPLOYEES'=>'Angestellte:',
'LBL_OTHER_EMAIL_ADDRESS'=>'andere E-Mail:',
'LBL_ANY_EMAIL'=>'weitere E-Mail:',
'LBL_OWNERSHIP'=>'Besitzer:',
'LBL_RATING'=>'Bewertung:',
'LBL_INDUSTRY'=>'Branche:',
'LBL_SIC_CODE'=>'Börsen Code:',
'LBL_TYPE'=>'Typ:',
'LBL_ANNUAL_REVENUE'=>'Jahresumsatz:',
'LBL_ADDRESS_INFORMATION'=>'Addresse',
'LBL_Quote_INFORMATION'=>'Organisation',
'LBL_CUSTOM_INFORMATION'=>'zusätzliche Information',
'LBL_BILLING_ADDRESS'=>'Rechnungadresse:',
'LBL_SHIPPING_ADDRESS'=>'Lieferadresse:',
'LBL_ANY_ADDRESS'=>'weitere Addresse:',
'LBL_CITY'=>'Ort:',
'LBL_STATE'=>'Bundesland:',
'LBL_POSTAL_CODE'=>'PLZ:',
'LBL_COUNTRY'=>'Land:',
'LBL_DESCRIPTION_INFORMATION'=>'Zusatzinformationen',
'LBL_DESCRIPTION'=>'Beschreibung:',
'NTC_COPY_BILLING_ADDRESS'=>'kopiere Rechnungsadressea auf Lieferadresse',
'NTC_COPY_SHIPPING_ADDRESS'=>'kopiere Lieferadresse auf Rechnungsadresse',
'NTC_REMOVE_MEMBER_ORG_CONFIRMATION'=>'Möchten Sie diesen Eintrag löschen?',
'LBL_DUPLICATE'=>'eventuell doppelte Organisation angelegt',
'MSG_DUPLICATE' => 'Das Anlegen dieser Organisation führt möglicherweise zu einer doppelten Eintragung. Sie können entweder mit der Auswahl einer Organisation aus der untenstehenden Liste fortfahren oder einen neue Organisation anlegen.',

'LBL_INVITEE'=>'Personen',
'ERR_DELETE_RECORD'=>"Zum Löschen muss mindestens ein Eintrag markiert sein.",

'LBL_SELECT_ACCOUNT'=>'Organisation wählen',
'LBL_GENERAL_INFORMATION'=>'Allgemein',

//for v4 release added
'LBL_NEW_POTENTIAL'=>'Neues Verkaufspotential',
'LBL_POTENTIAL_TITLE'=>'Verkaufspotentiale',

'LBL_NEW_TASK'=>'neue Aufgabe',
'LBL_TASK_TITLE'=>'Aufgaben',
'LBL_NEW_CALL'=>'neuer Anruf',
'LBL_CALL_TITLE'=>'Anrufe',
'LBL_NEW_MEETING'=>'neue Beprechung',
'LBL_MEETING_TITLE'=>'Besprechungen',
'LBL_NEW_EMAIL'=>'neue E-Mail',
'LBL_EMAIL_TITLE'=>'E-Mails',
'LBL_NEW_CONTACT'=>'neue Person',
'LBL_CONTACT_TITLE'=>'Personen',

//Added fields after RC1 - Release
'LBL_ALL'=>'All',
'LBL_PROSPECT'=>'potentieller Kunde',
'LBL_INVESTOR'=>'Investor',
'LBL_RESELLER'=>'Wiederverkäufer',
'LBL_PARTNER'=>'Partner',

// Added for 4GA
'LBL_TOOL_FORM_TITLE'=>'Organisations-Tools',
//Added for 4GA
'Subject'=>'Titel',
'Potential Name'=>'Verkaufspotential',
'Quote Stage'=>'Angebotsstufe',
'Valid Till'=>'Ablauf Bindefrist',
'Team'=>'Team',
'Contact Name'=>'Person',
'Currency'=>'Währung',
'Carrier'=>'Transporteur',
'Sub Total'=>'Zwischensumme',
'Shipping'=>'Versanddatum',
'Inventory Manager'=>'Bestandsmanager',
'Type'=>'Type',
'Tax'=>'Steuer',
'Total'=>'Total',
'Product Name'=>'Produktname',
'Assigned To'=>'zuständig ',
'Billing Address'=>'Rechnungsadresse Strasse',
'Shipping Address'=>'Lieferadresse Strasse',
'Billing City'=>'Rechnungsadresse Ort',
'Billing State'=>'Rechnungsadresse Bundesland',
'Billing Code'=>'Rechnungsadresse PLZ',
'Billing Country'=>'Rechnungsadresse Land',
'Billing Po Box'=>'Rechnungsadresse Postfachnr.',
'Shipping Po Box'=>'Lieferadresse Postfachnr.',
'Shipping City'=>'Lieferadresse Ort',
'Shipping State'=>'Lieferadresse Bundesland',
'Shipping Code'=>'Lieferadresse PLZ',
'Shipping Country'=>'Lieferadresse Land',
'Created Time'=>'erstellt',
'Modified Time'=>'geändert',
'Description'=>'Beschreibung',
'Account Name'=>'Organisation',
'Terms & Conditions'=>'Konditionen',
//Quote Info
'LBL_QUOTE_INFORMATION'=>'Angebot',
'LBL_TERMS_INFORMATION'=>'Liefer- und Zahlungsbedingungen',
'LBL_QUOTE'=>'Angebot:',

//Added during 4.2 release
'LBL_SUBJECT'=>'Titel:',
'LBL_POTENTIAL_NAME'=>'Verkaufspotential:',
'LBL_ACCOUNT_NAME'=>'Organisation:',
'LBL_QUOTE_STAGE'=>'Angebotsstufe:',
'LBL_MY_TOP_QUOTE'=>'meine top Angebote',
//'Quote ID'=>'Angebots-ID',
'Quote'=>'Angebot',

//Added for existing Picklist Entries

'Created'=>'erzeugt',
'Delivered'=>'geliefert',
'Reviewed'=>'durchgesehen',
'Accepted'=>'akzeptiert',
'Rejected'=>'abgelehnt',

'FedEx'=>'FedEx',
'UPS'=>'UPS',
'USPS'=>'USPS',
'DHL'=>'DHL',
'BlueDart'=>'Post',
'Sales Tax'=>'MwSt.',

//fehlende Einträge für Berichte
'Tax Type'=>'Steuertyp',
'Discount Percent'=>'Rabatt (%)',
'Discount Amount'=>'Rabatt',
'Adjustment'=>'Anpassung',
'S&H Amount'=>'Versandkosten',

//Added after 5.0.4 GA
'Quote No'=>'Angebotsnr.',

'SINGLE_Quotes'=>'Angebot',
'Add Service Contract'=>'hinzufügen Servicevertrag',
'Quotes ID'=>'Angebots-ID',

'Terms & Conditions'=>'Geschäftsbedingungen',
);

?>